<template>
  <el-dialog
    width="60%"
    title="库位"
    top="5vh"
    :visible.sync="innerVisible"
    append-to-body
    @close="$emit('update:currshowlist', false)"
    :show="currshowlist"
    class="location-dialog"
  >
    <ttable
      :table="table"
      @handleSelectionChange="handleSelectionChange"
      @currentChange="handleCurrentChange"
      :uploadInfo="uploadInfo"
      :prelang="prelang"
      :options="options"
      :bottomOffset="255"
      :ajaxFun="ajaxFun"
      ref="commonLocationTable"
    >
      <template #toolbar></template>
    </ttable>

    <div slot="footer" class="dialog-footer">
      <el-button @click="innerVisible = false">取 消</el-button>
      <el-button type="primary" @click="saveSelectRow">确 定</el-button>
    </div>
  </el-dialog>
</template>
<script>
import ttable from '@/views/common/ztt-table'
// import {fetchListExt as fetchList } from '@/api/warehouse/location'、
import { fetchList } from '@/api/warehouse/location'

import { remote } from '../../api/admin/dict'
import { loadWarehouse } from '../../api/warehouse/location'
export default {
  props: {
    currshowlist: {
      type: Boolean,
      default: false
    }
    // queryParam: {
    //   type: Object,
    //   default: () => {
    //     return {}
    //   }
    // },
  },
  data() {
    return {
      // paramObj:{},
      ajaxFun: fetchList,
      innerVisible: false,
      warehouseOptions: [],
      locTypeOptions: [],
      mulLocation: [],
      uploadInfo: {
        // 是否展示上传EXCEL以及对应的url
        isShow: false,
        url: ''
      },
      prelang: 'operation',
      options: {
        height: 300, // 默认高度-为了表头固定
        stripe: true, // 是否为斑马纹 table
        highlightCurrentRow: false, // 是否要高亮当前行
        border: true, // 是否有纵向边框
        lazy: false, // 是否需要懒加载
        fit: true, // 列的宽度是否自撑开
        multiSelect: false, //
        seqNo: true,
        isRefresh: true, // 是否显示刷新按钮
        isShowHide: true, // 是否显示显影按钮
        isSearch: false, // 高级查询按钮
        defaultOrderBy: { column: 'id', direction: 'desc' }
      },
      table: {
        total: 0,
        currentPage: 1,
        pageSize: 20,
        data: [],
        // 标题
        column: [
          // 工厂
          {
            minWidth: '140',
            prop: 'factoryName',
            label: '工厂',
            sort: true,
            isTrue: true,
            isSearch: true,
            searchInfoType: 'text'
          },

          // {minWidth:'140',prop:"workstationNo",label:"工作站编号",sort: true,isTrue:true,isSearch:false,searchInfoType:'text'},

          // 库位编号
          {
            minWidth: '120',
            prop: 'locNo',
            label: '库位编号',
            sort: true,
            isTrue: true,
            isSearch: true,
            searchInfoType: 'text'
          },
          // 库位名称
          {
            minWidth: '200',
            prop: 'locName',
            label: '库位名称',
            sort: true,
            isTrue: true,
            isSearch: true,
            searchInfoType: 'text'
          },
          // 库位描述
          {
            minWidth: '140',
            prop: 'locDesc',
            label: '库位描述',
            sort: true,
            isTrue: true,
            isSearch: false,
            searchInfoType: 'text'
          },
          // 库位类型
          {
            minWidth: '120',
            prop: 'locType',
            label: '库位类型',
            sort: true,
            isTrue: true,
            formatter: this.locationType,
            isSearch: true,
            searchInfoType: 'text'
          },
          // 库位地址
          {
            minWidth: '200',
            prop: 'locAddr',
            label: '库位地址',
            sort: true,
            isTrue: true,
            isSearch: false,
            searchInfoType: 'text'
          },
          // 库位地图
          {
            minWidth: '140',
            prop: 'locMap',
            label: '库位地图',
            sort: true,
            isTrue: true,
            isSearch: false,
            searchInfoType: 'text'
          },
          // 库位状态
          {
            minWidth: '120',
            prop: 'locStatus',
            label: '库位状态',
            sort: true,
            isTrue: true,
            isSearch: true,
            searchInfoType: 'select',
            optList: () => {
              return this.getLocationStatusOptionList()
            },
            formatter: (row, column, cellValue) => {
              return cellValue == 1 ? '使用' : '停产'
            }
          },
          // 备注
          {
            minWidth: '200',
            prop: 'locRemark',
            label: '备注',
            sort: true,
            isTrue: true,
            isSearch: false,
            searchInfoType: 'text'
          },
          // 创建时间
          {
            minWidth: '200',
            width: '300',
            prop: 'createTime',
            label: '创建时间',
            sort: true,
            isTrue: true,
            isSearch: true,
            searchInfoType: 'datetimerange'
          },
          // 所属仓库分组
          {
            minWidth: '200',
            prop: 'locGroup',
            label: '所属仓库分组',
            sort: true,
            isTrue: true,
            isSearch: true,
            searchInfoType: 'text',
            formatter: this.warehouseLocGroup,
            optList: () => {
              return this.getWarehouseLocGroupList()
            }
          }
        ]
      },
      addOrUpdateVisible: false,
      locationOptionList: [
        {
          value: 1,
          label: '使用'
        },
        {
          value: 0,
          label: '停产'
        }
      ]
    }
  },
  components: {
    ttable
  },
  created() {
    this.getLocTypeCache('warehouse_type') // 获取定时任务运行时状态
    this.initWarehouseSelect()
  },
  methods: {
    saveSelectRow() {
      this.$emit('listenToLocationEvent', this.currentRow)

      // this.queryParam = {};
      // this.paramObj={};

      this.innerVisible = false
    },
    handleCurrentChange(val) {
      this.currentRow = val
    },
    // 获取数据列表
    getData() {
      // debugger;
      if (this.$refs.commonLocationTable !== undefined) {
        // if(this.queryParam){
        //     this.paramObj = Object.assign(this.queryParam);
        // }
        this.$refs.commonLocationTable.getDataList()
      }
    },
    getWarehouseLocGroupList() {
      return this.warehouseOptions
    },
    // 将id进行匹配显示为对应的仓库分组
    warehouseLocGroup(row, column, cellValue) {
      this.warehouseOptions.forEach((obj) => {
        if (obj.value == cellValue) {
          cellValue = obj.label
        }
      })
      return cellValue
    },
    /**
     * 获取字典显示名称并缓存
     */
    getLocTypeCache(type) {
      remote(type).then((response) => {
        const code = response.data.code
        if (code === 0) {
          const _data = response.data.data
          this.locTypeOptions = _data
        }
      })
    },
    /**
     * 获取字典定时任务执行状态字典值显示名称
     */
    locationType(row, column, cellValue) {
      this.locTypeOptions.forEach((obj) => {
        if (obj.value == cellValue) {
          cellValue = obj.label
        }
      })
      return cellValue
    },
    // 获取仓库的数据
    initWarehouseSelect() {
      loadWarehouse().then((res) => {
        this.warehouseOptions = JSON.parse(
          JSON.stringify(res.data)
            .replace(/id/g, 'value')
            .replace(/warehouseName/g, 'label')
        )
      })
    },
    getLocationStatusOptionList() {
      return this.locationOptionList
    },
    // table自带事件
    handleSelectionChange(val) {
      this.multipleSelection = val
    }
  },
  watch: {
    currshowlist() {
      this.innerVisible = this.currshowlist
      if (this.currshowlist) {
        this.$nextTick(() => {
          this.getData()
        })
      }
    }
  }
}
</script>
<style>
.location-dialog .el-dialog__header {
  padding: 10px 20px 10px;
}
.location-dialog .el-dialog__header .el-dialog__headerbtn {
  top: 10px;
}
.location-dialog .el-dialog__body {
  padding: 5px 20px;
}

.location-dialog .el-dialog__footer {
  padding: 5px 20px 10px;
}

.location-dialog .el-dialog__body .avue-crud__pagination {
  margin-top: 0px;
  margin-bottom: 5px;
}
</style>
